@@ -1,4 +1,5 @@
-{-# LANGUAGE MultiParamTypeClasses, UndecidableInstances #-}
+{-# LANGUAGE MultiParamTypeClasses, FlexibleContexts, FlexibleInstances,
+             UndecidableInstances #-}
 {-  darcs-monitor - Darcs repository monitor
     Copyright © 2007 Antti-Juhani Kaijanaho
 
